@@ -1,13 +1,47 @@
-from flask import jsonify,g,flash,url_for,Markup
-to_gig_d = 1024*1024*1024
+from flask import jsonify,g,url_for,Markup
+from flask import flash as flask_flash
+to_gig_d = 1000*1000*1000
 import datetime
 
 from hiddifypanel.panel.database import db
-from hiddifypanel.models import StrConfig,BoolConfig,User,Domain,get_hconfigs,Proxy,hconfig,ConfigEnum
+from hiddifypanel.models import StrConfig,BoolConfig,User,Domain,get_hconfigs,Proxy,hconfig,ConfigEnum,DomainType
 import urllib
 from flask_babelex import lazy_gettext as _
+from flask_babelex import gettext as __
 from hiddifypanel import xray_api
 
+
+def add_temporary_access():
+    import random
+
+    random_port=random.randint(30000, 50000)
+    exec_command(f'/opt/hiddify-config/hiddify-panel/temporary_access.sh {random_port} &')
+    # iptableparm=f'PREROUTING -p tcp --dport {random_port} -j REDIRECT --to-port 9000'
+    # exec_command(f'iptables -t nat -I {iptableparm}')
+    # exec_command(f'echo "iptables -t nat -D {iptableparm}" | at now + 4 hour')
+    
+    # iptableparm=f'INPUT -p tcp --dport {random_port} -j ACCEPT'
+    # exec_command(f'iptables -I {iptableparm}')
+    # exec_command(f'echo "iptables -D {iptableparm}" | at now + 4 hour')
+
+    temp_admin_link=f"http://{get_ip(4)}:{random_port}{get_admin_path()}"
+    g.temp_admin_link=temp_admin_link
+    
+
+def get_admin_path():
+    proxy_path=hconfig(ConfigEnum.proxy_path)
+    admin_secret=hconfig(ConfigEnum.admin_secret)        
+    return (f"/{proxy_path}/{admin_secret}/admin/")
+
+def exec_command(cmd,cwd=None):
+    try:
+        import os
+        os.system(cmd)
+    except Exception as e:
+        print(e)
+
+    
+
 def auth(function):
     def wrapper(*args,**kwargs):
         if g.user_uuid==None:
@@ -37,14 +71,14 @@ def asset_url(path):
 def update_usage():
         
         res={}
-        for user in db.session.query(User).all():
-            if (datetime.date.today()-user.last_reset_time).days>=30:
+        for user in User.query.all():
+            if user.monthly and (datetime.date.today()-user.last_reset_time).days>=30:
                 user.last_reset_time=datetime.date.today()
-                if user.current_usage_GB > user.monthly_usage_limit_GB:
+                if user.current_usage_GB > user.usage_limit_GB:
                     xray_api.add_client(user.uuid)
                 user.current_usage_GB=0
 
-            d = xray_api.get_usage(user.uuid)
+            d = xray_api.get_usage(user.uuid,reset=True)
             
             if d == None:
                res[user.uuid]="No value" 
@@ -52,7 +86,7 @@ def update_usage():
                 in_gig=(d)/to_gig_d
                 res[user.uuid]=in_gig
                 user.current_usage_GB += in_gig
-            if user.current_usage_GB > user.monthly_usage_limit_GB:
+            if user.current_usage_GB > user.usage_limit_GB:
                 xray_api.remove_client(user.uuid)
                 res[user.uuid]+=" !OUT of USAGE! Client Removed"
                     
@@ -63,11 +97,15 @@ def update_usage():
 
 
 def all_configs():
-    return {
-        "users": [u.to_dict() for u in User.query.filter((User.monthly_usage_limit_GB>User.current_usage_GB)).filter(User.expiry_time>=datetime.date.today()).all()],
+    configs={
+        "users": [u.to_dict() for u in User.query.filter((User.usage_limit_GB>User.current_usage_GB)).filter(User.expiry_time>=datetime.date.today()).all()],
         "domains": [u.to_dict() for u in Domain.query.all()],
         "hconfigs": get_hconfigs()
         }
+    for d in configs['domains']:
+        d['domain']=d['domain'].lower()
+
+    return configs
     
 
 def get_ip(version,retry=3):
@@ -102,6 +140,37 @@ def get_available_proxies():
     return proxies
 
 
-def flash_config_success():
-    apply_btn=f"<a href='{url_for('admin.Actions:apply_configs')}' class='btn btn-primary'>"+_("admin.config.apply_configs")+"</a>"
-    flash(Markup(_('config.validation-success',link=apply_btn)), 'success')
\ No newline at end of file
+def flash_config_success(full_install=False):
+    url=url_for('admin.Actions:'+('reinstall' if full_install else 'apply_configs'))
+    apply_btn=f"<a href='{url}' class='btn btn-primary form_post'>"+_("admin.config.apply_configs")+"</a>"
+    flash((_('config.validation-success',link=apply_btn)), 'success')
+
+# Importing socket library 
+import socket 
+
+# Function to display hostname and 
+# IP address 
+def get_domain_ip(domain): 
+    import socket
+    try: 
+        host_ip = socket.gethostbyname(domain) 
+        return host_ip
+    except: 
+        return None
+
+
+
+def get_user_link(uuid,domain):
+        proxy_path=hconfig(ConfigEnum.proxy_path)
+        text=domain.domain
+        if domain.mode==DomainType.cdn:
+            text=f'<span class="badge badge-success" >{_("domain.cdn")}</span>'+text        
+        return f"<a target='_blank' href='https://{domain.domain}/{proxy_path}/{uuid}/'><span class='badge badge-info ltr'>{text}</span></a>"
+
+
+
+def flash(message,category):
+    print(message)
+    return flask_flash(Markup(message),category)
+
+
