@@ -119,6 +119,10 @@ def _v6():
         *make_proxy_rows(["XTLS direct vless"])
     ])
 
+def _v7():
+        db.session.bulk_save_objects([
+            StrConfig(key=ConfigEnum.cdn_forced_host,value=""),
+        ])
 def init_db():
     
     try:
